@@ -12,10 +12,12 @@ class SwitchCommand(Command):
         show_output: bool,
         target_repo: Optional[str] = None,
         target_addling: Optional[str] = None,
+        target_pricing_list: Optional[str] = None,
     ) -> None:
         self._receiver: Receiver = receiver
         self._target_repo: Optional[str] = target_repo
         self._target_addling: Optional[str] = target_addling
+        self._target_pricing_list: Optional[str] = target_pricing_list
         self._show_output: bool = show_output
 
     def execute(self) -> None:
@@ -27,3 +29,7 @@ class SwitchCommand(Command):
             self._receiver.switch_server_rails_addling(
                 target_addling=self._target_addling, show_output=self._show_output
             )
+        if self._target_pricing_list:
+            self._receiver.switch_billing_rails_pricing_list(
+                target_pricing_list=self._target_pricing_list, show_output=self._show_output
+            )
