@@ -1517,7 +1517,7 @@ class Receiver:
                 self._shared_logic_commands["choose_yarn_version"],
                 self._shared_logic_commands["choose_node_version"],
                 self._core_commands["git_fetch_all"],
-                self._core_commands["ember_pre_release"],
+                f"ember release -l --prerelease {self._get_valid_pre_release_name()}",
                 self._npm_release_commands["npm_set_parasut_registry"],
                 self._npm_release_commands["npm_login"],
                 self._npm_release_commands["npm_publish"],
@@ -1533,7 +1533,7 @@ class Receiver:
                 self._shared_logic_commands["choose_yarn_version"],
                 self._shared_logic_commands["choose_node_version"],
                 self._core_commands["git_fetch_all"],
-                self._core_commands["ember_pre_release_all_yes"],
+                f"ember release -l --prerelease {self._get_valid_pre_release_name()} --yes",
                 self._npm_auto_release_commands["npm_set_parasut_registry"],
                 self._npm_auto_release_commands["npm_login"],
                 self._npm_auto_release_commands["npm_publish"],
@@ -1585,7 +1585,7 @@ class Receiver:
                 self._ui_library_commands["choose_yarn_version"],
                 self._ui_library_commands["choose_node_version"],
                 self._core_commands["git_fetch_all"],
-                self._core_commands["ember_pre_release"],
+                f"ember release -l --prerelease {self._get_valid_pre_release_name()}",
                 self._npm_release_commands["npm_set_parasut_registry"],
                 self._npm_release_commands["npm_login"],
                 self._npm_release_commands["npm_publish"],
@@ -1601,7 +1601,7 @@ class Receiver:
                 self._ui_library_commands["choose_yarn_version"],
                 self._ui_library_commands["choose_node_version"],
                 self._core_commands["git_fetch_all"],
-                self._core_commands["ember_pre_release_all_yes"],
+                f"ember release -l --prerelease {self._get_valid_pre_release_name()} --yes",
                 self._npm_auto_release_commands["npm_set_parasut_registry"],
                 self._npm_auto_release_commands["npm_login"],
                 self._npm_auto_release_commands["npm_publish"],
